local PoleFlag = ...

PoleFlag:dofile("scripts/compFlagFlaping.lua")

-- Apply building asset processor
PoleFlag:registerAssetProcessor("models/utility/pole.fbx", {
    DataType = "BUILDING_ASSET_PROCESSOR"
})

-- Create default building part registering function 
function registerDefaultBuildingPart(_nodePrefix)
    PoleFlag:register({
		DataType = "BUILDING_PART",
		Id = _nodePrefix .. "_PART",
		ConstructorData = {
                     DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
                     CoreObjectPrefab = _nodePrefix .. "_PREFAB"
                }
    })
end

-- Register common prefab nodes
PoleFlag:registerAssetId("models/utility/pole.fbx/Prefab/poleFlag/Pole/step_0_RootPart", PoleFlagPrefix .. "_ROOT_PREFAB")
PoleFlag:registerAssetId("models/utility/pole.fbx/Prefab/poleFlag/Pole/step_2_Tiling2Part", PoleFlagPrefix .. "_TILING2_PREFAB")
PoleFlag:registerAssetId("models/utility/pole.fbx/Prefab/poleFlag/Pole/step_1_Tiling3Part", PoleFlagPrefix .. "_TILING3_PREFAB")

registerDefaultBuildingPart(PoleFlagPrefix .. "_TILING2")
registerDefaultBuildingPart(PoleFlagPrefix .. "_TILING3")

function registerFlag(_fbxName, _assetId)

    PoleFlag:registerAssetProcessor("models/flags/" .. _fbxName .. ".fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
    })

-- Register common prefab nodes
    PoleFlag:registerAssetId("models/flags/" .. _fbxName .. ".fbx/Prefab/poleFlag/Pole/step_3_TopPart", PoleFlagPrefix .. _assetId .. "_TOP_PREFAB")

-- Register simple building part assets
    registerDefaultBuildingPart(PoleFlagPrefix .. _assetId .. "_TOP")

-- Register the pole flag part
    PoleFlag:register({
	DataType = "BUILDING_PART",
	Id = PoleFlagPrefix .. _assetId .. "_ROOT_PART",
	Name = PoleFlagPrefix .. _assetId .. "_ROOT_NAME",
	Description = PoleFlagPrefix .. _assetId .. "_ROOT_DESC",
	Category = "CORE",
        BuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {1, 1} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
        }},
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = PoleFlagPrefix .. "_ROOT_PREFAB",
		EndPart = PoleFlagPrefix .. _assetId .. "_TOP_PART",
		FillerList = {
			PoleFlagPrefix .. "_TILING2_PART"
                },
		BasementFillerList = {
			PoleFlagPrefix .. "_TILING3_PART"
         	},
		MinimumScale = 0,
		IsVertical = true
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = _NoSandbox*0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
                        { Resource = "WOOD", Quantity = _NoSandbox*2 },
			{ Resource = "WOOLEN_CLOTH", Quantity = _NoSandbox*2 }
		}
	},
        DesirabilityModifiers = {
                {
                        Desirability = "DESIRABILITY_RESIDENTIAL",
                        Radius = 20,
                        Value = 0.1
                }
        }
    })

    PoleFlag:registerPrefabComponent("models/flags/" .. _fbxName .. ".fbx/Prefab/poleFlag/Pole/step_3_TopPart", {
	DataType = PoleFlagPrefix .. "_FLAPING_COMP",
	Enabled = true
    })
end

registerFlag("Flame", "_FLAME")

